import json

import requests


class XesWork:
    def __init__(self, work_id):
        self.url = 'https://code.xueersi.com/api/compilers/v2/{}?id={}'.format(work_id, work_id)
        self.headers = {'Content-Type': 'application/json'}
        self.a = requests.get(self.url, headers=self.headers)
        self.a.encoding = 'gzip'
        self.p = self.a.text
        #self.respon = self.p.encode('ascii').decode('unicode_escape')
        self.response = json.loads(self.p, strict=False)
        #self.response = self.respons.replace('{', ',').replace('}', ',').replace('\"', '').split(',')
        #del self.response[0]
        self.picture_url = "https://livefile.xesimg.com/programme/assets/7ddec8b247e63d9971addecd8b752b3d.jpg"

    def get_name(self):
        #return self.response['data']['name']
        return self.response

    def get_description(self):
        if self.response['data']['description'] == '':
            return None
        else:
            return self.response['data']['description']

    def get_likes(self):
        return self.response['data']['likes']

    def get_unlikes(self):
        return self.response['data']['unlikes']

    def get_favorites(self):
        return self.response['data']['favorites']

    def get_adapt_numbers(self):
        return self.response['data']['source_code_views']

    def download_icon(self):
        import os
        os.makedirs('./', exist_ok=True)
        from urllib.request import urlretrieve
        urlretrieve(self.picture_url, './icon.jpg')
        os.system('icon.jpg')
        string = "start explorer " + os.getcwd()
        os.system(string)
        return True

    def get_author_name(self):
        return self.response['data']['username']

    def get_author_id(self):
        return self.response['data']['user_id']

    def get_work_tags(self):
        tags = self.response['data']['tags']
        list_of_tags = tags.split()
        return list_of_tags

    def get_hot(self):
        return self.response['data']['popular_score']

    def get_views(self):
        return self.response['data']['views']

    def get_first_published_time(self):
        return self.response['data']['published_at']

    def get_latest_modified_time(self):
        return self.response['data']['modified_at']

    def get_latest_updated_time(self):
        return self.response['data']['updated_at']

    def get_created_time(self):
        return self.response['data']['created_at']

    def is_hidden_code(self):
        if self.response['data']['hidden_code'] == 2:
            return False
        else:
            return True


class XesUserSpace:
    def __init__(self, user_id):
        self.url_1 = 'https://code.xueersi.com/api/space/index?user_id=' + str(user_id)
        self.url_2 = 'https://code.xueersi.com/api/space/profile?user_id=' + str(user_id)
        self.headers = {'Content-Type': 'application/json',}
        self.p_1 = requests.get(self.url_1, headers=self.headers).text
        self.p_2 = requests.get(self.url_2, headers=self.headers).text
        self.response_index = json.loads(self.p_1, strict=False)
        self.response_profile = json.loads(self.p_2, strict=False)
        self.head_url = self.response_profile['data']['avater_path']

    def download_user_head(self):
        #类似于分类讨论【捂脸】
        if self.head_url[-3, -1] == 'gif':
            import os
            import shutil
            os.makedirs('./', exist_ok=False)
            from urllib.request import urlretrieve
            urlretrieve(self.head_url, './icon.gif')
            shutil.move(os.getcwd() + '/icon.gif', os.path.join(os.path.expanduser("~"), 'Desktop'))
            return '已成功将该用户头像下载到桌面'
        elif self.head_url[-3, -1] == 'jpg':
            import os
            import shutil
            os.makedirs('./', exist_ok=False)
            from urllib.request import urlretrieve
            urlretrieve(self.head_url, './icon.jpg')
            shutil.move(os.getcwd() + '/icon.jpg', os.path.join(os.path.expanduser("~"), 'Desktop'))
            return '已成功将该用户头像下载到桌面'
        else:
            import os
            import shutil
            os.makedirs('./', exist_ok=False)
            from urllib.request import urlretrieve
            urlretrieve(self.head_url, './icon.png')
            shutil.move(os.getcwd() + '/icon.png', os.path.join(os.path.expanduser("~"), 'Desktop'))
            return '已成功将该用户头像下载到桌面'

    def get_fans_number(self):
        #这孩子多少粉了？
        return self.response_profile['data']['fans']

    def get_follows_number(self):
        #这孩子有几个偶像（关注了几个人）？
        return self.response_profile['data']['follows']

    def is_follow(self):
        #你有没有关注他呢？？？
        if self.response_profile['data']['is_follow'] == 1:
            return True
        else:
            return False

    def get_realname(self):
        #他真名叫啥？
        return self.response_profile['data']['realname']

    def get_sign(self):
        #个性签名是什么？
        return self.response_profile['data']['signature']

    def get_number_of_works(self):
        #他一共有多少作品（加上没发布的）？
        return self.response_index['data']['overview']['works']

    def get_number_of_likes(self):
        #他的所有作品一共获了多少赞？
        return self.response_index['data']['overview']['likes']

    def get_number_of_views(self):
        #总浏览量
        return self.response_index['data']['overview']['views']

    def get_adapted_number(self):
        #被改编多少次？
        return self.response_index['data']['overview']['source_code_views']

    def get_favorites(self):
        #被收藏多少次？
        return self.response_index['data']['overview']['favorites']

    def get_first_eight_fans(self):
        #获取他前八个粉丝的姓名和id
        a_list = []
        for i in self.response_index['data']['fans']['data']:
            a_list.append((i['id'], i['realname']))
        return a_list

    def get_first_eight_favourites(self):
        #获取他前八个收藏的id、name、作者id和作者名
        a_list = []
        for i in self.response_index['data']['favourites']['data']:
            a_list.append((i['id'], i['name'], i['user_id'], i['user_name']))
        return a_list

    def get_representative_work(self):
        #代表作
        return self.response_index['data']['representative_work']['name']



import numpy as np
from huoyanlib.numpy import _raise_hnumpyerror_int_str


def length(x):
    try:
        y = np.array(x)
    except TypeError:
        _raise_hnumpyerror_int_str()
    return np.linalg.norm(y)


def equal(a, b):
    return np.all(a == b)



from pkg_resources import find_distributions
from sys import executable,exit
sys.executable
_path = executable.split("python.exe")[0]+"lib\\site-packages"
_res = find_distributions(_path)
_list=[]

_down_from=['https://pypi.tuna.tsinghua.edu.cn/simple', 'https://pypi.douban.com/simple','https://mirrors.aliyun.com/pypi/simple/', 'http://pypi.mirrors.ustc.edu.cn/simple/']
for _item in _res:
    _item=_item.hashcmp
    v=list(_item)
    v[0]=str(v[0])
    _item=tuple(v)
    del v
    _list.append(_item)

# for x in _list:
#     print(x)
# exit()
def pip_cmd(cmd):
    import os,sys

    if "linux" in sys.platform:
        mit="sudo apt-get"
    elif "darwin" in sys.platform:
        mit=f"sudo {sys.executable} -m pip"
    elif "win" in sys.platform:
        mit=f"{sys.executable} -m pip"
    os.system(f"{mit} {cmd}")

def get_interpreter():
    import sys
    return sys.executable

def get_packages():
    return _list

def look_for_package(pakage, ver=False):
    Ls = get_packages()
    for x in Ls:
        if x[2] == pakage and((not ver) or (ver==x[0])):
            return x
    return False
# print(look_for_package('pycparser','2.20'))#'2.20', -1, 'pycparser'
# exit()
def upgrade(pakage):
    # import os
    # if type(pakage) != type(" "):
    #     pakage = "".join(pakage)
    pip_cmd(f"install --upgrade {pakage} -i {_down_from[1]}")


def install(pakage, interpreter=None):
    # import os
    # if type(pakage) != type(" "):
    #     pakage = " ".join(pakage)
    # if interpreter == None:
    #     interpreter = get_interpreter()
    print(pakage)
    pip_cmd(f"install {pakage} -i {_down_from[1]}")
# upgrade("xingyunlib")

def dump_pip_list(filename):
    pip_cmd(f"freeze > {filename}")

# dump_pip_list("free.txt")
def load_pip_list(filename, interpreter=None):
    pip_cmd(f"install -r {filename}")
# load_pip_list("free.txt")

def get_all_pakages():
    return
# print(find_packages("xingyunlib"))
# exit()
exit()



import PIL
"""
package:
    获取放置于里面的静态文件
args:
    filename:文件名
"""

def where_data(filename):
    import os
    basepath = os.path.abspath(__file__)
    folder = os.path.dirname(basepath)
    data_path = os.path.join(folder, filename)
    return data_path
print(where_data("xes\\AIspeak.py"))


from pikacloudlib.http_spider import  *
from pikacloudlib.xesapi import *
from pikacloudlib.tkinter_extend import *
from pikacloudlib.code import *
from pikacloudlib.image import *
from pikacloudlib.user import *
from pikacloudlib.xesuser import *
from pikacloudlib.data import *
from pikacloudlib.color import *
from pikacloudlib.err import *
from pikacloudlib.print_format import *
from pikacloudlib.render import *
from pikacloudlib.xesapi import *
# from pikacloudlib.pygame_extend import *


class HuoYanLibRequestsError(Exception):
    """Nothing"""


def _raise_huoyanlibrequesterror_sys():
    raise HuoYanLibRequestsError(
        'length of object \'sys.argv\' is not enough, please use 360 explorer -- xueersi running this function'
    )
